<?php 

$lang['user_title'] = 'Користувачі';
$lang['role_title'] = 'Ролі';
$lang['rule_title'] = 'Правила';

$lang['fail'] = 'Помилка збереження даних';
$lang['success'] = 'Дані успішно збережені';

$lang['acl_action_name'] = 'Дії';
$lang['acl_role_name'] = 'Роль';
$lang['login'] = 'Логін';
$lang['password'] = 'Пароль';
$lang['photo'] = 'Фото';
$lang['email'] = 'Email';
$lang['birth_date'] = 'Дата народження';
$lang['registered'] = 'Зареєстрований';
$lang['Default language'] = 'Мова за замовчуванням';
$lang['confirmed'] = 'Підтверджений';
$lang['acl_active'] = 'Активне';
$lang['Name'] = 'Ім’я';
$lang['Surname'] = 'Прізвище';
$lang['acl_role_parent_id'] = 'Успадковано';
$lang['acl_resource_name'] = 'Ресурс';
$lang['acl_resource_alias'] = 'Псевдонім ресурсу';
$lang['pass_changed'] = 'Пароль змінено';
$lang['pass_fail'] = 'Помилка зміни пароля';
$lang['change_pass_dialog'] = 'Змінити пароль';
$lang['change_info'] = 'Змінити інформацію користувача';
$lang['password'] = 'Пароль';
$lang['password1'] = 'Пароль ще раз';
$lang['add_new_user'] = 'користувача';
$lang['add_new_acl_resource'] = 'ресурс';
$lang['add_new_acl_role'] = 'роль';

$lang['back_to_list'] = 'Повернутись до списку';