<?php

$lang['title'] = 'Install';
$lang['ln_menu_title'] = 'Steps';

$lang['step_nav_items'] = array(
    'check_folders' => 'Verifying access catalogs',
    'configuration' => 'System configuration',
    'database' => 'Data base configuration',
    'modules' => 'Install modules'
);
$lang['check_folders_info'] = 'Catalogues marked below should be writable (775)';

$lang['ln_folder_name'] = 'Catalogue';
$lang['ln_folder_status'] = 'Status';
$lang['ln_btn_next'] = 'Next';

$lang['admin_page'] = 'Admin. page';
$lang['ln_encryption_key'] = 'Secret key';
$lang['ln_language'] = 'Languages';
$lang['user_data'] = 'Super user';
$lang['login'] = 'Login';
$lang['pass'] = 'Password';
$lang['cpass'] = 'Password again';

$lang['db_data'] = 'Data base';
$lang['hostname'] = 'Host';
$lang['database'] = 'Data base';

// ACL
$lang['acl_title'] = 'ACL';
$lang['acl_actions'] = array(
    'view_user' => 'Users list',
    'insert_user' => 'Add user',
    'edit_user' => 'Edit user',
    'delete_user' => 'Delete user',
    'change_user_pass' => 'Change user password',
    'view_role' => 'Roles list',
    'insert_role' => 'Add role',
    'edit_role' => 'Edit role',
    'delete_role' => 'Delete role',
    'edit_rule' => 'Access rules'
);
$lang['system_title'] = 'System';
$lang['system_actions'] = array(
    'view_amenu' => 'View admin menu',
    'view_admin' => 'Administration panel',
    'edit_amenu' => 'Edit admin menu',
    'module_manager' => 'Install/Delete modules',
    'language_manager' => 'Languages configuration',
    'system_settings' => 'Settings',
    'backup_db' => 'Data base backup'
);

$lang['finish_info'] = 'System installed.';
$lang['admin_link_txt'] = 'Enter to admin panel';