<?php (defined('BASEPATH')) OR exit('No direct script access allowed');

/* load the MX_Router class */
require realpath('vendor/wiredesignz/hmvc/third_party/MX/Router.php');

class RT_Router extends MX_Router {}