<?php

namespace Ciext\Controller;

abstract class AbstractCLIController extends \MX_Controller
{

    public function __construct()
    {
        parent::__construct();
        if (!$this->input->is_cli_request()) {

            return $this->response('Only CLI');
        }
    }

    /**
     * Output data
     * @param string $content
     * @return void
     */
    public function response($content = '')
    {
        die((string) $content . PHP_EOL);
    }

}
