body{
    background: #eee
}
.login{
    width: 400px;
    margin: 10% auto 20px;
    float: none;
    background: #fff;
    padding: 30px;
    box-sizing: border-box;
    border-radius: 5px;
    box-shadow: 0 2px 3px rgba(0, 0, 0, 0.1);
    overflow: hidden
}
.login .logo{
    background: url("/assets/components/ciext/img/logo.png") no-repeat center center;
    background-size: contain;
    width: 200px;
    height: 75px;
    margin: 0 auto 35px;
}
.login form{
    width: 100%;
    margin: 0 auto;
    box-sizing: border-box;
    float: left
}
.login input[type="text"], .login input[type="password"]{
    width: 100%;
    border-radius: 0;
    box-shadow: none;
    height: 35px;
    box-sizing: border-box;
    padding: 0 0 0 10px;
    line-height: 35px;
}
.login label{
    font-size: 14px;
    margin: 5px 0 20px;
    color: #7d7d7d;
}
.login button {
    font-size: 14px;
    padding: 4px 30px;
    width: 100%;
    height: 40px;
    border-radius: 0;
    background: #1976d2;
    border-color: #1976d2;
    box-shadow: none
}
.login button.btn-primary:hover{
    background: #1e84e9;
    border-color: #1e84e9
}
footer {
    float: left;
    font-size: 14px;
    text-align: center;
    width: 100%;
}
footer p:last-of-type {
    float: none;
}